@@ -1,9 +1,9 @@
 from datetime import datetime
 
 import validators
-from ._odata_filter import _compose_filter, _compose_select
+from ._odata_filter import _compose_filter, _compose_select, _compose_expand
 from ._str_match_algo import fuzzy_match
-from .guardpoint_dataclasses import Cardholder, SortAlgorithm
+from .guardpoint_dataclasses import Cardholder, SortAlgorithm, Area
 from .guardpoint_error import GuardPointError
 from .guardpoint_utils import GuardPointResponse
 
@@ -33,6 +33,19 @@ class CardholdersAPI:
 
         return True
 
+    def update_card_holder_area(self, cardholder_uid: str, area: Area):
+        if not validators.uuid(cardholder_uid):
+            raise ValueError(f'Malformed Cardholder UID {cardholder_uid}')
+
+        if not validators.uuid(area.uid):
+            raise ValueError(f'Malformed Area UID {area.uid}')
+
+        cardholder = Cardholder()
+        cardholder.uid = cardholder_uid
+        cardholder.insideAreaUID = area.uid
+
+        return self.update_card_holder(cardholder)
+
     def update_card_holder(self, cardholder: Cardholder):
         if not validators.uuid(cardholder.uid):
             raise ValueError(f'Malformed Cardholder UID {cardholder.uid}')
@@ -157,6 +170,7 @@ class CardholdersAPI:
                 raise GuardPointError(str(code))
 
         return json_body['value'][0]['photo']
+
     def _get_card_holder(self, uid):
         if not validators.uuid(uid):
             raise ValueError(f'Malformed UID {uid}')
@@ -188,7 +202,8 @@ class CardholdersAPI:
     def get_card_holders(self, offset: int = 0, limit: int = 10, search_terms: str = None, areas: list = None,
                          filter_expired: bool = False, cardholder_type_name: str = None,
                          sort_algorithm: SortAlgorithm = SortAlgorithm.SERVER_DEFAULT, threshold: int = 75,
-                         count: bool = False, earliest_last_pass: datetime = None, property_ignore_list: list = None):
+                         count: bool = False, earliest_last_pass: datetime = None,
+                         select_ignore_list: list = None, select_include_list: list = None):
 
         url = "/odata/API_Cardholders"
 
@@ -198,22 +213,17 @@ class CardholdersAPI:
                                      cardholder_type_name=cardholder_type_name,
                                      earliest_last_pass=earliest_last_pass)
 
-        select_str = _compose_select(property_ignore_list)
+        select_str = _compose_select(select_ignore_list, select_include_list)
 
-        url_query_params = ("?" + select_str + filter_str)
+        expand_str = _compose_expand(select_ignore_list, select_include_list)
+
+        url_query_params = ("?" + select_str + expand_str + filter_str)
         # url_query_params = ("?" + filter_str)
 
         if count:
             url_query_params += "$count=true&$top=0"
         else:
-            url_query_params += "$expand=" \
-                                "cardholderType($select=typeName)," \
-                                "cards," \
-                                "cardholderPersonalDetail," \
-                                "cardholderCustomizedField," \
-                                "insideArea," \
-                                "securityGroup&" \
-                                "$orderby=fromDateValid%20desc&"
+            url_query_params += "$orderby=fromDateValid%20desc&"
             url_query_params += "$top=" + str(limit) + "&$skip=" + str(offset)
 
         code, json_body = self.gp_json_query("GET", url=(url + url_query_params))
