@@ -27,14 +27,16 @@ class GuardPointAsync:
                          threshold=75,
                          count=False,
                          earliest_last_pass=None,
-                         property_ignore_list=None):
+                         select_ignore_list=None,
+                         select_include_list=None):
 
         future = self.executor.submit(self.gp.get_card_holders, offset=offset, limit=limit, search_terms=search_terms,
                                       cardholder_type_name=cardholder_type_name, areas=areas,
                                       filter_expired=filter_expired,
                                       sort_algorithm=sort_algorithm, threshold=threshold,
                                       count=count, earliest_last_pass=earliest_last_pass,
-                                      property_ignore_list=property_ignore_list)
+                                      select_ignore_list=select_ignore_list,
+                                      select_include_list=select_include_list)
         callback = GPAsyncCallBack(on_finished)
         future.add_done_callback(callback.handle_future)
 
